@@ -25,7 +25,6 @@ function display_help()
   echo "    [--address-sanitizer] build with address sanitizer enabled. Uses hip-clang to compile"
   echo "    [--matrices-dir] existing client matrices directory"
   echo "    [--matrices-dir-install] install client matrices directory"
-  echo "    [--rm-legacy-include-dir] Remove legacy include dir Packaging added for file/folder reorg backward compatibility."
 }
 
 # This function is helpful for dockerfiles that do not have sudo installed, but the default user is root
@@ -138,12 +137,14 @@ install_packages( )
   local library_dependencies_centos_6=( "epel-release" "make" "cmake3" "gcc-c++" "rpm-build" )
   local library_dependencies_centos_7=( "epel-release" "make" "cmake3" "gcc-c++" "rpm-build" )
   local library_dependencies_centos_8=( "epel-release" "make" "cmake3" "gcc-c++" "rpm-build" )
+  local library_dependencies_centos_9=( "epel-release" "make" "cmake3" "gcc-c++" "rpm-build" )
   local library_dependencies_fedora=( "make" "cmake" "gcc-c++" "libcxx-devel" "rpm-build" "numactl-libs" )
   local library_dependencies_sles=( "make" "cmake" "gcc-c++" "rpm-build" "pkg-config" "dpkg" )
 
   local client_dependencies_centos_6=( "gcc-gfortran" )
   local client_dependencies_centos_7=( "devtoolset-7-gcc-gfortran" )
   local client_dependencies_centos_8=( "gcc-gfortran" )
+  local client_dependencies_centos_9=( "gcc-gfortran" )
   local client_dependencies_fedora=( "gcc-gfortran" )
   local client_dependencies_sles=( "gcc-fortran" )
 
@@ -153,6 +154,7 @@ install_packages( )
     else
       library_dependencies_centos_7+=( "numactl-libs" )
       library_dependencies_centos_8+=( "numactl-libs" )
+      library_dependencies_centos_9+=( "numactl-libs" )
     fi
   fi
 
@@ -179,7 +181,13 @@ install_packages( )
 #     yum -y update brings *all* installed packages up to date
 #     without seeking user approval
 #     elevate_if_not_root yum -y update
-      if [[ "${MAJORVERSION}" == 8 ]]; then
+      if [[ "${MAJORVERSION}" == 9 ]]; then
+        install_yum_packages "${library_dependencies_centos_9[@]}"
+
+        if [[ "${build_clients}" == true ]]; then
+          install_yum_packages "${client_dependencies_centos_9[@]}"
+        fi
+      elif [[ "${MAJORVERSION}" == 8 ]]; then
         install_yum_packages "${library_dependencies_centos_8[@]}"
 
         if [[ "${build_clients}" == true ]]; then
@@ -268,7 +276,6 @@ install_prefix=hipsparse-install
 rocm_path=/opt/rocm
 build_relocatable=false
 build_address_sanitizer=false
-build_freorg_bkwdcomp=false
 compiler=${CXX}
 
 # #################################################
@@ -332,9 +339,6 @@ while true; do
         build_address_sanitizer=true
         compiler=amdclang++
         shift ;;
-    --rm-legacy-include-dir)
-        build_freorg_bkwdcomp=false
-        shift ;;
     --matrices-dir)
         matrices_dir=${2}
         if [[ "${matrices_dir}" == "" ]];then
@@ -361,7 +365,7 @@ done
 
 # Note 'compiler' variable not changed after this point. This ensures that everything is built with the same compiler
 # provided by the user through either setting CXX externally (in which case compiler=${CXX} followed by CXX=${compiler})
-# or through using --compiler option. This is important so that googletest and hipsparse are built with the same 
+# or through using --compiler option. This is important so that googletest and hipsparse are built with the same
 # compiler to ensure settings like position independent code is consistent when linking.
 CXX=${compiler}
 
@@ -486,13 +490,6 @@ pushd .
     cmake_common_options="$cmake_common_options -DBUILD_ADDRESS_SANITIZER=ON"
   fi
 
-  # freorg backward compatible support enable
-  if [[ "${build_freorg_bkwdcomp}" == true ]]; then
-    cmake_common_options="${cmake_common_options} -DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=ON"
-  else
-    cmake_common_options="${cmake_common_options} -DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=OFF"
-  fi
- 
   # library type
   if [[ "${build_static}" == true ]]; then
     cmake_common_options="${cmake_common_options} -DBUILD_SHARED_LIBS=OFF"
